==> haskell-hscolour-1.25-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hscolour
version:              1.25
visibility:           public
id:                   hscolour-1.25-L2oNThTGlT5KhgfnkQEbGQ
key:                  hscolour-1.25-L2oNThTGlT5KhgfnkQEbGQ
license:              LicenseRef-LGPL
copyright:            2003-2023 Malcolm Wallace; 2006 Bjorn Bringert
maintainer:           Malcolm Wallace
author:               Malcolm Wallace
homepage:             http://code.haskell.org/~malcolm/hscolour/
synopsis:             Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.

category:             Language
abi:                  00b3d31cbd1023ed8f6329a42f7677ef
exposed:              True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY

import-dirs:          /usr/lib/ghc-9.2.8/site-local/hscolour-1.25
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hscolour-1.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hscolour
hs-libraries:         HShscolour-1.25-L2oNThTGlT5KhgfnkQEbGQ
depends:              base-4.16.4.0 containers-0.6.5.1
haddock-interfaces:   /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html:         /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hscolour-1.25-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hscolour
version:              1.25
visibility:           public
id:                   hscolour-1.25-61St7PjQxrJB3Zc5RdCary
key:                  hscolour-1.25-61St7PjQxrJB3Zc5RdCary
license:              LicenseRef-LGPL
copyright:            2003-2023 Malcolm Wallace; 2006 Bjorn Bringert
maintainer:           Malcolm Wallace
author:               Malcolm Wallace
homepage:             http://code.haskell.org/~malcolm/hscolour/
synopsis:             Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.

category:             Language
abi:                  5ff64ea6642318441739e75dc41583a9
exposed:              True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hscolour-1.25
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hscolour-1.25
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hscolour-1.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hscolour
hs-libraries:         HShscolour-1.25-61St7PjQxrJB3Zc5RdCary
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html:         /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
